@@ -6,9 +6,10 @@ call_fun_in_BSgenomeForge <- function(fun, ...)
     S4Vectors:::load_package_gracefully("BSgenomeForge", "in order to use ",
                                         fun, "() in BioC >= 3.19")
     msg <- c(fun, "() has moved from BSgenome to the BSgenomeForge package, ",
-             "and is formally deprecated in BSgenome >= 1.75.1. Please call ",
-             "BSgenomeForge::", fun, "() to get rid of this warning.")
-    .Deprecated(msg=wmsg(msg))
+             "and BSgenome::", fun, "() is now formally defunct in BioC ",
+             "3.23 (after being deprecated in BioC 3.22). Please call ",
+             "BSgenomeForge::", fun, "().")
+    .Defunct(msg=wmsg(msg))
     FUN <- base::get(fun, envir=asNamespace("BSgenomeForge"), inherits=FALSE)
     do.call(FUN, list(...))
 }
